package mongodb_protocol_crawler_go

import (
	"encoding/json"
	"github.com/stretchr/testify/assert"
	"loafle.com/overflow/crawler_go"
	"loafle.com/overflow/of_rpc_go"
	"loafle.com/overflow/of_rpc_go/client"
	"loafle.com/overflow/of_rpc_go/models/param"
	"log"
	"testing"
	"time"
)

func setConfig() crawler.Crawler {

	r := NewMongoDBHealthCrawler()

	m := make(map[string]interface{}, 0)

	m["ip"] = "192.168.1.104"
	m["port"] = "27017"
	m["portType"] = "tcp"
	m["ssl"] = false

	r.PutConfig("ad", m)

	return r
}

func TestMatch(t *testing.T) {
	// test config
	r := setConfig()

	out := param.Output{}
	r.Get("ad", &out)

	var check bool
	json.Unmarshal(out.Data, &check)

	assert.Equal(t, true, check)
}

func start() {
	r := setConfig()

	of_rpc.AddDelegate("ad", r)
	err := of_rpc.StartJSONRPC()
	if err != nil {
		log.Fatal(err)
	}
}

func TestRPC(t *testing.T) {
	go start()
	time.Sleep(2 * time.Second)

	in := param.Input{
		Name: "ad",
		Id:   "ad",
	}

	result, err := client.InvokeJSONRPCGet("50000", in)

	if err != nil {
		t.Fatal(err)
	}

	var check bool
	json.Unmarshal(result.Data, &check)
	assert.Equal(t, true, check)
}

//
//import (
//	"encoding/json"
//	"github.com/stretchr/testify/assert"
//	"loafle.com/overflow/of_rpc/json/client"
//	"loafle.com/overflow/of_rpc/models/param"
//	"loafle.com/overflow/of_rpc/models/protocol"
//	"testing"
//	"time"
//)
//
//func TestCheck(t *testing.T) {
//	b, _ := check("192.168.1.104", 27017, true)
//	assert.Equal(t, true, b)
//}
//
//func TestRPC(t *testing.T) {
//
//	go start()
//	time.Sleep(time.Second * 2)
//
//	p := protocol.HealthRequest{IsSSL: true}
//	b, _ := json.Marshal(p)
//
//	in := param.Input{Ip: "192.168.1.104", Port: 27017, Data: b}
//
//	re, _ := client.InvokeJSONRPC("50000", in)
//	var m protocol.HealthResponse
//	json.Unmarshal(re.Data, &m)
//
//	assert.Equal(t, true, m.IsMatch)
//}
