package mssql_protocol_crawler_go

import (
	"encoding/json"
	"github.com/stretchr/testify/assert"
	"loafle.com/overflow/crawler_go"
	"loafle.com/overflow/of_rpc_go"
	"loafle.com/overflow/of_rpc_go/client"
	"loafle.com/overflow/of_rpc_go/models/param"
	"log"
	"testing"
	"time"
)

func setConfig() crawler.Crawler {
	
	r := NewMSSqlHeahthCrawler()
	
	m := make(map[string]interface{}, 0)
	
	m["ip"] = "192.168.1.106"
	m["port"] = "1433"
	m["portType"] = "tcp"
	m["ssl"] = false
	
	r.PutConfig("r", m)
	
	return r
}

func TestMatch(t *testing.T) {
	// test config
	r := setConfig()
	
	out := param.Output{}
	r.Get("r", &out)
	
	var check bool
	json.Unmarshal(out.Data, &check)
	
	assert.Equal(t, true, check)
}

func start() {
	r := setConfig()
	
	of_rpc.AddDelegate("r", r)
	err := of_rpc.StartJSONRPC()
	if err != nil {
		log.Fatal(err)
	}
}

func TestRPC(t *testing.T) {
	go start()
	time.Sleep(2 * time.Second)
	
	in := param.Input{
		Name: "r",
		Id:   "r",
	}
	
	result, err := client.InvokeJSONRPCGet("50000", in)
	
	if err != nil {
		t.Fatal(err)
	}
	
	var check bool
	json.Unmarshal(result.Data, &check)
	assert.Equal(t, true, check)
}


//
//import (
//	"testing"
//	"github.com/stretchr/testify/assert"
//)
//
//func TestMatch(t *testing.T) {
//	b, err := check("192.168.1.106", 1433)
//	if err != nil {
//		t.Error(err)
//	}
//	assert.Equal(t, true, b)
//}

